// Copyright (c) 1999, A.H. van den Boogaard

#include "ftutils.h"

StopWatch::StopWatch( bool directstart ):total_seconds(0),lap_seconds(0),
                                       total_msecs(0),lap_msecs(0),active(false)
{
   if ( directstart ) start();
}

void StopWatch::update()
{
   if ( running() )
   {
      timeb current_time;
      ftime( &current_time );

      long seconds_interval( current_time.time - start_time.time );
      int  msecs_interval( current_time.millitm - start_time.millitm );

      total_seconds += seconds_interval;
      total_msecs   += msecs_interval;
      lap_seconds   += seconds_interval;
      lap_msecs     += msecs_interval;

      start_time = current_time;
   }
}

void StopWatch::start()
{
   if ( !running() )
   {
      ftime( &start_time );
      active = true;
   }
}

void StopWatch::stop()
{
   if ( running() )
   {
      update();
      active = false;
   }
}

void StopWatch::reset()
{
   total_seconds = 0;
   total_msecs   = 0;
   lap_seconds = 0;
   lap_msecs   = 0;

   if ( running() ) ftime( &start_time );
}

double StopWatch::elapsed()
{
   update();

   double dsecs(0);
   dsecs += double(total_seconds);
   dsecs += double(total_msecs)/1000.0;

   return dsecs;
}

double StopWatch::lap()
{
   update();

   double dsecs(0);
   dsecs += double(lap_seconds);
   dsecs += double(lap_msecs)/1000.0;

   lap_seconds = 0;
   lap_msecs   = 0;

   return dsecs;
}
