// Copyright (c) 2000, A.H. van den Boogaard

// For compilers that support precompilation, includes "wx/wx.h".
#include "wx/wxprec.h"
 
#ifdef __BORLANDC__
#pragma hdrstop
#endif
 
#ifndef WX_PRECOMP
#include "wx/wx.h"
#endif

#include "printing.h"
#include "winfem2.h"

bool FEAPrintout::OnPrintPage(int page)
{
    wxDC *dc = GetDC();
    if (dc)
    {
        DrawPage(dc);
 
        dc->SetDeviceOrigin(0, 0);
        dc->SetUserScale(1.0, 1.0);
 
        char buf[200];
        sprintf(buf, "PAGE %d", page);
        dc->DrawText(buf, 10, 10);
 
        return TRUE;
    }
    else
        return FALSE;
}
 
bool FEAPrintout::OnBeginDocument(int startPage, int endPage)
{
    if (!wxPrintout::OnBeginDocument(startPage, endPage))
        return FALSE;
 
    return TRUE;
}

void FEAPrintout::GetPageInfo(int *minPage, int *maxPage, int *selPageFrom, int
*selPageTo)
{
    *minPage = 0;
    *maxPage = 1;
    *selPageFrom = 1;
    *selPageTo = 1;
}
 
bool FEAPrintout::HasPage(int pageNum)
{
    return (pageNum == 1);
}

void FEAPrintout::DrawPage(wxDC *dc)
{
    int w, h;
 
    MyFrame *frame( get_main_frame() );

    int gx, gy;
    frame->canvas->GetSize( &gx, &gy );
 
    float maxX = float(gx);
    float maxY = float(gy);

    // Let's have at least 50 device units margin
    float marginX = 50;
    float marginY = 50;
 
    // Add the margin to the graphic size
    maxX += (2*marginX);
    maxY += (2*marginY);
 
    // Get the size of the DC in pixels
    dc->GetSize(&w, &h);
 
    // Calculate a suitable scaling factor
    float scaleX=(float)(w/maxX);
    float scaleY=(float)(h/maxY);
 
    // Use x or y scaling factor, whichever fits on the DC
    float actualScale = wxMin(scaleX,scaleY);
 
    // Calculate the position on the DC for centring the graphic
    float posX = (float)((w - (gx*actualScale))/2.0);
    float posY = (float)((h - (gy*actualScale))/2.0);
 
    // Set the scale and origin
    dc->SetUserScale(actualScale, actualScale);
    dc->SetDeviceOrigin( (long)posX, (long)posY );
 
    frame->Draw(*dc);
}
