// Copyright (c) 1999, A.H. van den Boogaard

#ifndef THERMAL_H
#define THERMAL_H

#include "material.h"

/* advance declaration */
class LinearThermal_type;

class LinearThermal_Point:public FeaTure::Thermal_Point
{
   protected:
      LinearThermal_type *parameters;
      FeaTure::Vector phi;
      FeaTure::Vector newphi;
      double Temp, newTemp;
//      double accumulation;

   public:
      LinearThermal_Point( LinearThermal_type *mat, FeaTure::StressType str );
      ~LinearThermal_Point();

      FeaTure::Matrix get_conduction_matrix() const;
      void set_flux_increment( const FeaTure::Vector& flux_increment );
      virtual void set_potential_increment( double Tinc );
      void finish_increment();
      double get_rho_c() const;
      double get_accumulation() const;
      FeaTure::Vector get_flux() const;

      void GetRestartData( FeaTure::CollectArray &data ) const;
      void PutRestartData( const FeaTure::CollectArray &data );
};

class LinearThermal_type: public FeaTure::Thermal_type
{
   private:
      double lambda, capacity;

   public:
      LinearThermal_type( int matnr );
      ~LinearThermal_type();

      int set_conductivity( double lambda );
      double get_conductivity() const;
      int set_capacity( double c );
      double get_capacity() const;

#ifdef NOVARIABLERETURN
      FeaTure::Material_Point* new_Material_Point( FeaTure::StressType st );
#else
      LinearThermal_Point* new_Material_Point( FeaTure::StressType st );
#endif
      bool symmetric() const { return true; }
};

#endif /* THERMAL_H */
