// Copyright (c) 2000, A.H. van den Boogaard

#include "valnumbr.h"

DoubleTextValidator::DoubleTextValidator( double *val )
  : wxTextValidator( wxFILTER_NUMERIC ), m_doubleValue(val)
{
   m_string = new wxString;
   m_stringValue = m_string;
   *m_stringValue << *m_doubleValue;
}

DoubleTextValidator::DoubleTextValidator( const DoubleTextValidator& val )
  : wxTextValidator( val ), m_doubleValue( val.m_doubleValue )
{
   m_string = new wxString;
   m_stringValue = m_string;
   *m_stringValue << *m_doubleValue;
}

DoubleTextValidator::~DoubleTextValidator()
{
   delete m_string;
}

bool DoubleTextValidator::Validate( wxWindow *parent )
{
   double tmp;
   if ( wxTextValidator::Validate( parent ) )
      return m_stringValue->ToDouble( &tmp );
   else
      return false;
}

bool DoubleTextValidator::TransferToWindow(void)
{
   m_stringValue->Empty();
   *m_stringValue << *m_doubleValue;
   return wxTextValidator::TransferToWindow();
}

bool DoubleTextValidator::TransferFromWindow(void)
{
   if ( wxTextValidator::TransferFromWindow() )
      return m_stringValue->ToDouble( m_doubleValue );
   else
      return false;
}

IntTextValidator::IntTextValidator( int *val )
  : wxTextValidator( wxFILTER_NUMERIC ), m_intValue(val)
{
   m_string = new wxString;
   m_stringValue = m_string;
   *m_stringValue << *m_intValue;
}

IntTextValidator::IntTextValidator( const IntTextValidator& val )
  : wxTextValidator( val ), m_intValue( val.m_intValue )
{
   m_string = new wxString;
   m_stringValue = m_string;
   *m_stringValue << *m_intValue;
}

IntTextValidator::~IntTextValidator()
{
   delete m_string;
}

bool IntTextValidator::Validate( wxWindow *parent )
{
   long tmp;
   if ( wxTextValidator::Validate( parent ) )
      return m_stringValue->ToLong( &tmp );
   else
      return false;
}

bool IntTextValidator::TransferToWindow(void)
{
   m_stringValue->Empty();
   *m_stringValue << *m_intValue;
   return wxTextValidator::TransferToWindow();
}

bool IntTextValidator::TransferFromWindow(void)
{
   if ( wxTextValidator::TransferFromWindow() )
   {
      long tmp;
      if ( m_stringValue->ToLong( &tmp ) )
      {
         *m_intValue = int(tmp);
         return true;
      }
      else
         return false;
   }
   else
      return false;
}
