// Copyright (c) 1999, A.H. van den Boogaard

#ifndef DOFS_H
#define DOFS_H

#include "cartvect.h"

namespace FeaTure
{

class Dof
{
  public:
    enum dof_fixed{ prescribed, fixed, free_dof };
    enum Type { u, r, t };
    enum Load { f, m, q };

  protected:
    Type       phys_type;
    dof_fixed  fix_type;
    Direction  dir;
    int        global_dof_nr;

  public:
    Dof();
    void set_direction( Direction dir );
    void set_dof_type( Type phys_type );
    void set_dof_fixed( dof_fixed fix_type );
    Direction get_direction() const;
    Type get_dof_type() const;
    int get_global_dof() const;
    void set_global_dof( int dofnr );
    void print() const;
    bool is_vector() const;
    bool is_scalar() const;
    bool is_free() const;
    bool is_fixed() const;
    bool is_prescribed() const;
};

class incDof:public Dof
{
  private:
    double total_value;

  public:
    incDof():Dof(),total_value(0.0){}

    void set_total( double value ){ total_value = value; }
    void add_to_total( double value ){ total_value += value; }
    virtual double get_total() const { return total_value; }
};

class itincDof:public incDof
{
  private:
    double incremental_value;

  public:
    itincDof():incDof(),incremental_value(0.0){}

    void set_increment( double value ){ incremental_value = value; }
    void add_to_increment( double value ){ incremental_value += value; }
    void add_increment_to_total() { add_to_total( incremental_value );
                                    incremental_value = 0.0; }
    double get_total() const { return incDof::get_total() + incremental_value; }
    double get_increment() const { return incremental_value; }
};

typedef itincDof* Dof_ptr;

class dof_sets
{
   private:
      struct dof_set
      {
         Dof_ptr global_dof;
         double  global_contribution;
      };

      dof_set* syst_dofs;
      int      nr_of_system_dofs;

   public:
      dof_sets();
      dof_sets( const dof_sets& in_set );
      ~dof_sets();

      void add_set( Dof_ptr p, double f );
      int  nr_of_dofs(){ return nr_of_system_dofs; }
      Dof_ptr dof( int i ){ return syst_dofs[i].global_dof; }
      double  contribution( int i ){ return syst_dofs[i].global_contribution; }
};

bool is_vector_dof( Dof::Type phys_type );
bool is_scalar_dof( Dof::Type phys_type );
void print_dof_type( Dof::Type type, std::ostream& out );

bool is_vector_load( Dof::Load type );
bool is_scalar_load( Dof::Load type );
void print_load_type( Dof::Load type, std::ostream& out );

Dof::Type conjugate_type( Dof::Load type );

} // namespace FeaTure

#endif /* DOFS_H */
